##########################################################################################
#Title: Replication code for "The role of market frictions in demand for prepaid electricity"
#Author: Megan Lang
#Date started: February 22, 2025
##########################################################################################


renv::restore(lockfile = "renv.lock", prompt = FALSE)
#setwd("Data")

#load("IPA_survey.Rda")
#load("TmtMM.Rda")


ipa_sur <- read.csv("ipa_sur.csv")
TmtMM <- read.csv("TmtMM.csv")

##########################################################################################
#Appendix materials
##########################################################################################
#####Figure A2: Weekly per capita consumption expenditures#####
eicv <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S0_S5_Household.dta")
eicv <- select(eicv, hhid, province, district, ur, region, weight, pop_wt, ubudehe = s0qb,
               light.source = s5cq16, elec.source = s5cq16a1, solar = s5cq16a21, 
               elec.exp.4wk = s5cq17, wall = s5dq1, roof = s5dq2, floor = s5dq3)

eicv.2 <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S8A3_expenditure.dta")
eicv.2 <- select(eicv.2, hhid, article = s8a3q0, exp.7days = s8a3q3)

eicv.food <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S8B_expenditure.dta")
eicv.food <- select(eicv.food, hhid, article = s8bq0, exp.7days = s8bq3)

# Add in total expenditures to give a sense of the price of solar 
total <- select(eicv.2, everything()) %>% group_by(hhid) %>% summarise(total.hhexp = sum(exp.7days, na.rm=T))
total.food <- select(eicv.food, everything()) %>% group_by(hhid) %>% 
  summarise(total.hhexp = sum(exp.7days, na.rm=T))
total <- rbind(total, total.food)
total <- select(total, everything()) %>% group_by(hhid) %>% summarise(total.exp = sum(total.hhexp, na.rm=T))

eicv <- left_join(eicv,total)

#Read in data about household composition
eicv.3 <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S1_S2_S3_S4_S6A_S6E_Person.dta")
eicv.3 <- select(eicv.3, hhid, sex = s1q1, age = s1q3y, absent = s1q7, length.absent = s1q8,
                 hh.member = s1q16) 
eicv.3$out <- as.numeric(gsub("([0-9]+).*$", "\\1", eicv.3$length.absent))
eicv.3 <- mutate(eicv.3, absent.ind = if_else(absent=="Yes",1,0),
                 length.num = if_else(is.na(out),0,out),
                 hh.ind = if_else(hh.member=="Yes",1,0),
                 adult = if_else(age>=18,1,0),
                 child = if_else(age<18,1,0),
                 present.proportion = 1-(length.num/12),
                 weighted.member = hh.ind*present.proportion,
                 male = if_else(sex=="Male",1,0),
                 female = if_else(sex=="Female",1,0))

hh.size <- select(eicv.3, everything()) %>% group_by(hhid) %>%
  summarise(hhsize = sum(hh.ind,na.rm=T),
            hhsize.wt = sum(weighted.member,na.rm=T),
            adults = sum(adult,na.rm=T),
            children = sum(child,na.rm=T),
            male.total = sum(male,na.rm=T),
            female.total = sum(female,na.rm=T))

eicv <- left_join(eicv, hh.size, by = "hhid")

eicv <- mutate(eicv, percap.exp = total.exp/hhsize)

quantiles <- quantile(eicv$percap.exp[which(eicv$ur!="Urban")], weights = eicv$weight[which(eicv$ur!="Urban")],
                      probs = seq(0, 1, 0.05), na.rm = TRUE)

eicv.exp.plot <- ggplot(data = eicv[which(eicv$ur!="Urban"),], aes(x = percap.exp, weight = weight)) + geom_histogram(binwidth = 100) + 
  coord_cartesian(xlim = c(0, 15000)) + geom_vline(xintercept = quantiles[6]) + geom_vline(xintercept = quantiles[11]) + 
  geom_vline(xintercept = quantiles[16]) + labs(x = "Daily Per Capita Expenditures (RWF)", y = "No. Households") + theme_bw() 

ggsave(filename="../Output/EICV_Exp.png", plot=eicv.exp.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

#####Figure A3: Travel times to mobile money agent#####
#Pull the question about time to reach a MM agent from each survey
rct.time.mm <- select(sur, time.mm = `About how long does it take you to reach the nearest mobile money agent when you go to pay for solar?`)
ipa.time.mm <- select(ipa.sur, time.mm = a1_agent)
time.mm <- rbind(rct.time.mm, ipa.time.mm)
time.mm$time.mm <- as.numeric(time.mm$time.mm)

mean(time.mm$time.mm[which(time.mm$time.mm<=1000)],na.rm=T)
median(time.mm$time.mm[which(time.mm$time.mm<=1000)],na.rm=T)

mm.dist <- ggplot(data = time.mm, aes(time.mm/60)) + coord_cartesian(xlim = c(0,6)) + 
  geom_histogram(binwidth = 0.25, color = "steelblue1", fill = "steelblue1") + 
  labs(x = "Hours to Reach the Nearest Mobile Money Agent", y = "Number of Consumers") + theme_bw() 

ggsave(filename="../Output/MM_Dist.png", plot=mm.dist, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

#####Figure A5: Use of mobile money agent to buy access time#####
go.mm <- select(ipa.sur, hhid, mm.pur = a2_paysoral) %>%
  mutate(times.mm = if_else(mm.pur=="None",0,
                            if_else(mm.pur=="1 time",1,
                                    if_else(mm.pur=="2 times",2,
                                            if_else(mm.pur=="3 times",3,
                                                    if_else(mm.pur=="4 times",4,
                                                            if_else(mm.pur=="5 times",5,
                                                                    as.double(NA))))))),
         counter=1) %>%
  group_by(times.mm) %>% summarise(total = sum(counter)) 

go.mm <- mutate(go.mm, pct = total/sum(go.mm$total))

mm.use.plot <- ggplot(data = go.mm, aes(x = times.mm, y = pct)) + 
  geom_bar(stat = "identity", color = "steelblue1",fill = "steelblue1") + 
  labs(x = "Times Visiting Mobile Money Agent to Pay for Solar of Past Five Purchases",
       y = "Proportion of Survey Respondents") + theme_bw() 

ggsave(filename="../Output/Time_MM_ToPay.png", plot=mm.use.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)


